<?php
/**
 * Jewel Blog functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Jewel_Blog
 */
define( 'THEME_ROOT', get_template_directory_uri() );
define( 'JEWEL_BLOG_CSS', get_template_directory_uri().'/css/');
define( 'JEWEL_BLOG_JS', get_template_directory_uri().'/js/');

if ( ! function_exists( 'jeweltheme_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function jeweltheme_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Jewel Blog, use a find and replace
	 * to change 'jewel-blog' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'jewel-blog', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );
	
	add_editor_style( 'css/editor-style.css' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	// Set Post Thumbnail Size
	set_post_thumbnail_size( 810, 450, true );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary Menu', 'jewel-blog' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list', 'gallery', 'caption', ) );
	
	add_image_size( 'small-thumb', '60', '60', true );

	/*
	 * Enable support for Post Formats.
	 * See https://developer.wordpress.org/themes/functionality/post-formats/
	 */
	add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'quote', 'link', ) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'jeweltheme_custom_background_args', array(
		'default-color' => 'ebe8e5',
		'default-image' => '',
	) ) );
}
endif; // jeweltheme_setup
add_action( 'after_setup_theme', 'jeweltheme_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function jeweltheme_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'jeweltheme_content_width', 800 );
}
add_action( 'after_setup_theme', 'jeweltheme_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function jeweltheme_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'jewel-blog' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );	
	register_sidebar( array(
		'name'          => esc_html__( 'Top Content', 'jewel-blog' ),
		'id'            => 'topcontent',
		'description'   => esc_html__( 'Front Page Only, use for Sliders','jewel-blog' ),
		'before_widget' => '<div class="abovecontent">',
		'after_widget'  => '</div>'
	) );
}
add_action( 'widgets_init', 'jeweltheme_widgets_init' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Custom Theme Functions
 */
require get_template_directory() . '/inc/theme-functions.php';













/*===================================================================================
 * Search Form
 * =================================================================================*/
add_filter('get_search_form', 'jewelblog_search_form');

function jewelblog_search_form($form) {
	$form = '<form class="search-form" method="get" action="' . esc_url( home_url( '/' ) ) . '" >
		<input class="search-field" type="text" name="s" id="s" value="' . esc_attr( get_search_query() ) . '" placeholder="Search" required>
		<button type="submit" id="search-submit" class="search-submit"><i class="fa fa-search"></i></button>
	</form>';
return $form;
}


// Post meta 
function jewelblog_entry_post_meta(){?>

	<div class="post-meta">
		<span class="author"><?php echo esc_html__('Posted by','jewel-blog');?> <?php printf('<a class="post-meta-element author vcard url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '"> ' . esc_html( get_the_author_meta('display_name') ) . '</a>' ); ?></span>
		<span class="comments"><?php echo esc_html__('With','jewel-blog');?> <?php comments_number( '0 Comment', '1 Comment', '% Comments' );?></span>
		<?php 
			$categories_list = get_the_category_list( esc_html__( ', ', 'jewel-blog' ) );
			if ( $categories_list ) {
			printf( '<span class="cat-links">' . esc_html__( 'In %1$s', 'jewel-blog' ) . '</span>', $categories_list ); // WPCS: XSS OK.
		} ?>
	</div><!-- /.post-meta -->
<?php } 



if ( ! function_exists( 'jewelblog_entry_readmore' ) ) {
  /**
   * Customize Read More link
   * @return string
   */
  function jewelblog_entry_readmore() {
    global $post;
    echo  '<p class="more-link"><a href="' . get_permalink( $post->ID ) . '">' . esc_html( 'Continue reading', 'infinity' ) . '</a></p>';
  }
}



function jewelblog_post_social_share(){
	global $post;
	?>
          <div class="post-share-buttons pull-right">
            <a href="https://www.facebook.com/sharer/sharer.php?u=<?php the_permalink(); ?>"
               onclick="window.open(this.href, '', 'menubar=no,toolbar=no,resizable=no,scrollbars=no,height=455,width=600'); return false;">
              <i class="fa fa-facebook"></i>
            </a>
            <a href="https://twitter.com/home?status=Check%20out%20this%20article:%20<?php echo rawurlencode(the_title('', '', false)); ?>%20-%20<?php the_permalink(); ?>"
               onclick="window.open(this.href, '', 'menubar=no,toolbar=no,resizable=no,scrollbars=no,height=455,width=600'); return false;">
              <i class="fa fa-twitter"></i>
            </a>
            <?php $pin_image = wp_get_attachment_url( get_post_thumbnail_id($post->ID)); ?>
            <a data-pin-do="skipLink" href="https://pinterest.com/pin/create/button/?url=<?php the_permalink(); ?>&amp;media=<?php echo esc_url($pin_image); ?>&amp;description=<?php echo rawurlencode(the_title('', '', false)); ?>"
               onclick="window.open(this.href, '', 'menubar=no,toolbar=no,resizable=no,scrollbars=no,height=455,width=600'); return false;">
              <i class="fa fa-pinterest"></i>
            </a>
            <a href="https://plus.google.com/share?url=<?php the_permalink(); ?>"
               onclick="window.open(this.href, '', 'menubar=no,toolbar=no,resizable=no,scrollbars=no,height=455,width=600'); return false;">
              <i class="fa fa-google-plus"></i>
            </a>
            <a href="mailto:<?php echo get_option( 'admin_email' ); ?>"><i class="fa fa-envelope-o"></i></a>
          </div>
    <?php

}        



/**
 * Custom comment layout
 * @param $comment
 * @param $args
 * @param $depth
 */
function ProWPTheme_comment($comment, $args, $depth) {
  $GLOBALS['comment'] = $comment; ?>
  <li <?php comment_class(); ?> id="li-comment-<?php comment_ID() ?>">
  <div id="comment-<?php comment_ID(); ?>">
    <div class="comment-author vcard">
      <?php echo get_avatar($comment,$size='100'); ?>
    </div>
    <div class="comment-content">
      <?php if ($comment->comment_approved == '0') : ?>
        <em><?php _e('Your comment is awaiting moderation.','jewel-blog') ?></em>
        <br />
      <?php endif; ?>
      <div class="metadata">
        <?php echo get_comment_author_link();?>
        <span class="date"><?php printf(__('%1$s','jewel-blog'), get_comment_date(),  get_comment_time()) ?></span>
        <?php edit_comment_link(__('(Edit)','jewel-blog'),'  ','') ?>
      </div>
      <?php comment_text() ?>
      <?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
    </div>
  </div>
<?php
}



/* Display a notice that can be dismissed */

add_action('admin_notices', 'pwpt_theme_admin_notice');

function pwpt_theme_admin_notice() {
    global $current_user ;
        $user_id = $current_user->ID;
    if ( ! get_user_meta($user_id, 'pwpt_ignore_notice') ) {
        echo '<div class="updated"><p>';         
        printf(__('<h4 style="font-size: 20px; color: #5FA52A; font-weight: normal; margin-bottom: 10px; margin-top: 5px;"><a href="https://jeweltheme.com/product/jewel-blog-blogging-wordpress-theme/" target="_blank">' . __('Get Jewel Blog PRO Today!'. 'jewel-blog') . '</a></h4>Check out Premium Features of <a href="https://jeweltheme.com/product/jewel-blog-blogging-wordpress-theme/" target="_blank">' . __('Jewel Blog PRO', 'jewel-blog') . '</a> Theme. Compare Why this Theme is really Awesome !!! <br>
            Jewel Theme, always express the power of WordPress. We are one of the best Team for creating stunning WordPress Themes - Plugins and Website Templates. <br>
            Check all of our <a href="http://jeweltheme.com/product-category/wordpress-themes/" target="_blank">Free and Premium WordPress Themes</a> and <a href="http://jeweltheme.com/product-category/wordpress-plugins/" target="_blank">WordPress Plugins </a> <a style="float: right;" href="%1$s">X</a>'), '?pwpt_ignore=0');
        echo "</p></div>";
    }
}
add_action('admin_init', 'pwpt_theme_ignore');


function pwpt_theme_ignore() {
    global $current_user;
        $user_id = $current_user->ID;
        if ( isset($_GET['pwpt_ignore']) && '0' == $_GET['pwpt_ignore'] ) {
             add_user_meta($user_id, 'pwpt_ignore_notice', 'true', true);
    }
}